# Django WebAuthn

[![Build Status](https://travis-ci.org/shemigon/django-webauthn.svg?branch=master)](https://travis-ci.org/shemigon/django-webauthn)

Django support of [WebAuthn](https://www.w3.org/TR/webauthn/) using [PyWARP](https://github.com/pyauth/pywarp).

Work has just started.
